@@ -27,7 +27,7 @@ def _transformers_log_filter(record):
 
 logging.getLogger("transformers.file_utils").addFilter(_transformers_log_filter)
 
-from allennlp.commands import main  # noqa
+from radgraph.allennlp.commands import main  # noqa
 
 
 def run():
