@@ -23,7 +23,7 @@ from requests.adapters import HTTPAdapter
 from requests.exceptions import ConnectionError
 from requests.packages.urllib3.util.retry import Retry
 
-from allennlp.common.tqdm import Tqdm
+from radgraph.allennlp.common.tqdm import Tqdm
 
 logger = logging.getLogger(__name__)
 
