@@ -6,14 +6,14 @@ from typing import Any, Dict, Iterable, Set, Union
 import torch
 from numpy.testing import assert_allclose
 
-from allennlp.commands.train import train_model_from_file
-from allennlp.common import Params
-from allennlp.common.testing.test_case import AllenNlpTestCase
-from allennlp.data import DatasetReader, Vocabulary
-from allennlp.data import DataLoader
-from allennlp.data.batch import Batch
-from allennlp.models import load_archive, Model
-from allennlp.training import GradientDescentTrainer
+from radgraph.allennlp.commands.train import train_model_from_file
+from radgraph.allennlp.common import Params
+from radgraph.allennlp.common.testing.test_case import AllenNlpTestCase
+from radgraph.allennlp.data import DatasetReader, Vocabulary
+from radgraph.allennlp.data import DataLoader
+from radgraph.allennlp.data.batch import Batch
+from radgraph.allennlp.models import load_archive, Model
+from radgraph.allennlp.training import GradientDescentTrainer
 
 
 class ModelTestCase(AllenNlpTestCase):
