@@ -33,8 +33,8 @@ import torch.distributed as dist
 from spacy.cli.download import download as spacy_download
 from spacy.language import Language as SpacyModelType
 
-from allennlp.common.checks import log_pytorch_version_info
-from allennlp.common.params import Params
+from radgraph.allennlp.common.checks import log_pytorch_version_info
+from radgraph.allennlp.common.params import Params
 
 try:
     import resource
@@ -66,7 +66,7 @@ def sanitize(x: Any) -> Any:
     can be serialized into JSON.
     """
     # Import here to avoid circular references
-    from allennlp.data.tokenizers.token import Token
+    from radgraph.allennlp.data.tokenizers.token import Token
 
     if isinstance(x, (str, float, int, bool)):
         # x is already serializable
