@@ -10,12 +10,12 @@ import jsonpickle
 import torch.distributed as dist
 from torch.utils.data import Dataset, IterableDataset, get_worker_info
 
-from allennlp.data.instance import Instance
-from allennlp.data.vocabulary import Vocabulary
-from allennlp.common import Tqdm, util
-from allennlp.common.checks import ConfigurationError
-from allennlp.common.file_utils import CacheFile
-from allennlp.common.registrable import Registrable
+from radgraph.allennlp.data.instance import Instance
+from radgraph.allennlp.data.vocabulary import Vocabulary
+from radgraph.allennlp.common import Tqdm, util
+from radgraph.allennlp.common.checks import ConfigurationError
+from radgraph.allennlp.common.file_utils import CacheFile
+from radgraph.allennlp.common.registrable import Registrable
 
 logger = logging.getLogger(__name__)
 
