@@ -2,7 +2,7 @@ from typing import Any, Dict, List
 
 from overrides import overrides
 
-from allennlp.data.fields.field import Field
+from radgraph.allennlp.data.fields.field import Field
 
 
 class FlagField(Field[Any]):
