@@ -5,9 +5,9 @@ from typing import Any, Dict, List, Optional, Tuple, Iterable
 from overrides import overrides
 from transformers import PreTrainedTokenizer
 
-from allennlp.common.util import sanitize_wordpiece
-from allennlp.data.tokenizers.token import Token
-from allennlp.data.tokenizers.tokenizer import Tokenizer
+from radgraph.allennlp.common.util import sanitize_wordpiece
+from radgraph.allennlp.data.tokenizers.token import Token
+from radgraph.allennlp.data.tokenizers.tokenizer import Tokenizer
 
 logger = logging.getLogger(__name__)
 
@@ -74,7 +74,7 @@ class PretrainedTransformerTokenizer(Tokenizer):
         tokenizer_kwargs.setdefault("use_fast", True)
         # Note: Just because we request a fast tokenizer doesn't mean we get one.
 
-        from allennlp.common import cached_transformers
+        from radgraph.allennlp.common import cached_transformers
 
         self.tokenizer = cached_transformers.get_tokenizer(
             model_name, add_special_tokens=False, **tokenizer_kwargs
@@ -116,7 +116,7 @@ class PretrainedTransformerTokenizer(Tokenizer):
         self.single_sequence_token_type_id = None
 
         # Reverse-engineer the tokenizer for two sequences
-        from allennlp.common import cached_transformers
+        from radgraph.allennlp.common import cached_transformers
 
         tokenizer_with_special_tokens = cached_transformers.get_tokenizer(
             model_name, add_special_tokens=True, **tokenizer_kwargs
