@@ -2,8 +2,8 @@ from typing import List
 
 from overrides import overrides
 
-from allennlp.data.tokenizers.token import Token
-from allennlp.data.tokenizers.tokenizer import Tokenizer
+from radgraph.allennlp.data.tokenizers.token import Token
+from radgraph.allennlp.data.tokenizers.tokenizer import Tokenizer
 
 
 @Tokenizer.register("whitespace")
