@@ -5,8 +5,8 @@ from typing import List, Tuple, Dict, Union
 
 import torch
 
-from allennlp.common.checks import ConfigurationError
-import allennlp.nn.util as util
+from radgraph.allennlp.common.checks import ConfigurationError
+import radgraph.allennlp.nn.util as util
 
 VITERBI_DECODING = Tuple[List[int], float]  # a list of tags, and a viterbi score
 
