@@ -1,6 +1,6 @@
 import torch
 
-from allennlp.nn import util
+from radgraph.allennlp.nn import util
 
 
 class MaskedLayerNorm(torch.nn.Module):
