@@ -1,6 +1,6 @@
 import torch
 
-from allennlp.common.registrable import Registrable
+from radgraph.allennlp.common.registrable import Registrable
 
 
 class MatrixAttention(torch.nn.Module, Registrable):
