@@ -12,13 +12,13 @@ import torch
 from overrides import overrides
 from torch.nn.functional import embedding
 
-from allennlp.common import Tqdm
-from allennlp.common.checks import ConfigurationError
-from allennlp.common.file_utils import cached_path, get_file_extension, is_url_or_existing_file
-from allennlp.data import Vocabulary
-from allennlp.modules.time_distributed import TimeDistributed
-from allennlp.modules.token_embedders.token_embedder import TokenEmbedder
-from allennlp.nn import util
+from radgraph.allennlp.common import Tqdm
+from radgraph.allennlp.common.checks import ConfigurationError
+from radgraph.allennlp.common.file_utils import cached_path, get_file_extension, is_url_or_existing_file
+from radgraph.allennlp.data import Vocabulary
+from radgraph.allennlp.modules.time_distributed import TimeDistributed
+from radgraph.allennlp.modules.token_embedders.token_embedder import TokenEmbedder
+from radgraph.allennlp.nn import util
 
 with warnings.catch_warnings():
     warnings.filterwarnings("ignore", category=FutureWarning)
