@@ -1,5 +1,5 @@
 import torch
-from allennlp.modules.token_embedders.token_embedder import TokenEmbedder
+from radgraph.allennlp.modules.token_embedders.token_embedder import TokenEmbedder
 
 
 @TokenEmbedder.register("empty")
