@@ -3,8 +3,8 @@ from typing import List, Tuple
 
 import torch
 
-from allennlp.common import FromParams
-from allennlp.nn.regularizers.regularizer import Regularizer
+from radgraph.allennlp.common import FromParams
+from radgraph.allennlp.nn.regularizers.regularizer import Regularizer
 
 
 class RegularizerApplicator(FromParams):
