@@ -1,8 +1,8 @@
 from overrides import overrides
 import torch
 
-from allennlp.training.metrics.average import Average
-from allennlp.training.metrics.metric import Metric
+from radgraph.allennlp.training.metrics.average import Average
+from radgraph.allennlp.training.metrics.metric import Metric
 
 
 @Metric.register("perplexity")
