@@ -1,9 +1,9 @@
 import logging
 
-from allennlp.data import DatasetReader
+from radgraph.allennlp.data import DatasetReader
 from overrides import overrides
 
-from allennlp_models.mc.dataset_readers.transformer_mc import TransformerMCReader
+from radgraph.allennlp_models.mc.dataset_readers.transformer_mc import TransformerMCReader
 
 logger = logging.getLogger(__name__)
 
@@ -16,12 +16,12 @@ class CommonsenseQaReader(TransformerMCReader):
 
     @overrides
     def _read(self, file_path: str):
-        from allennlp.common.file_utils import cached_path
+        from radgraph.allennlp.common.file_utils import cached_path
 
         file_path = cached_path(file_path)
 
         logger.info("Reading file at %s", file_path)
-        from allennlp.common.file_utils import json_lines_from_file
+        from radgraph.allennlp.common.file_utils import json_lines_from_file
 
         for json in json_lines_from_file(file_path):
             choices = [(choice["label"], choice["text"]) for choice in json["question"]["choices"]]
