@@ -1,9 +1,9 @@
 import logging
 
-from allennlp.data import DatasetReader
+from radgraph.allennlp.data import DatasetReader
 from overrides import overrides
 
-from allennlp_models.mc.dataset_readers.transformer_mc import TransformerMCReader
+from radgraph.allennlp_models.mc.dataset_readers.transformer_mc import TransformerMCReader
 
 logger = logging.getLogger(__name__)
 
@@ -24,17 +24,17 @@ class PiqaReader(TransformerMCReader):
                 "Could not determine file name for the labels corresponding to %s.", file_path
             )
 
-        from allennlp.common.file_utils import cached_path
+        from radgraph.allennlp.common.file_utils import cached_path
 
         file_path = cached_path(file_path)
 
         logger.info("Reading file at %s", file_path)
-        from allennlp.common.file_utils import json_lines_from_file
+        from radgraph.allennlp.common.file_utils import json_lines_from_file
 
         json_lines = json_lines_from_file(file_path)
 
         labels_path = cached_path(labels_path)
-        from allennlp.common.file_utils import text_lines_from_file
+        from radgraph.allennlp.common.file_utils import text_lines_from_file
 
         logger.info("Reading labels at %s", labels_path)
         labels_lines = text_lines_from_file(labels_path)
