@@ -7,7 +7,7 @@ import logging
 import string
 from typing import Any, Dict, List, Tuple, Optional
 
-from allennlp.data.fields import (
+from radgraph.allennlp.data.fields import (
     Field,
     TextField,
     IndexField,
@@ -16,9 +16,9 @@ from allennlp.data.fields import (
     ListField,
     SequenceLabelField,
 )
-from allennlp.data.instance import Instance
-from allennlp.data.token_indexers import TokenIndexer
-from allennlp.data.tokenizers import Token
+from radgraph.allennlp.data.instance import Instance
+from radgraph.allennlp.data.token_indexers import TokenIndexer
+from radgraph.allennlp.data.tokenizers import Token
 
 logger = logging.getLogger(__name__)
 
