@@ -6,17 +6,17 @@ import torch
 import torch.nn.functional as F
 from torch.nn.functional import nll_loss
 
-from allennlp.common.checks import check_dimensions_match
-from allennlp.data import Vocabulary
-from allennlp.models.model import Model
-from allennlp.modules import Seq2SeqEncoder, TimeDistributed, TextFieldEmbedder
-from allennlp.modules.input_variational_dropout import InputVariationalDropout
-from allennlp.modules.matrix_attention.linear_matrix_attention import LinearMatrixAttention
-from allennlp.nn import InitializerApplicator, util
-from allennlp.training.metrics import Average, BooleanAccuracy, CategoricalAccuracy
+from radgraph.allennlp.common.checks import check_dimensions_match
+from radgraph.allennlp.data import Vocabulary
+from radgraph.allennlp.models.model import Model
+from radgraph.allennlp.modules import Seq2SeqEncoder, TimeDistributed, TextFieldEmbedder
+from radgraph.allennlp.modules.input_variational_dropout import InputVariationalDropout
+from radgraph.allennlp.modules.matrix_attention.linear_matrix_attention import LinearMatrixAttention
+from radgraph.allennlp.nn import InitializerApplicator, util
+from radgraph.allennlp.training.metrics import Average, BooleanAccuracy, CategoricalAccuracy
 
-from allennlp_models.rc.tools import squad
-from allennlp_models.rc.models.utils import replace_masked_values_with_big_negative_number
+from radgraph.allennlp_models.rc.tools import squad
+from radgraph.allennlp_models.rc.models.utils import replace_masked_values_with_big_negative_number
 
 logger = logging.getLogger(__name__)
 
