@@ -6,17 +6,17 @@ import torch
 import torch.nn.functional as F
 from overrides import overrides
 
-from allennlp.data import Vocabulary
-from allennlp.models.model import Model
-from allennlp.modules.token_embedders import Embedding
-from allennlp.modules import FeedForward
-from allennlp.modules import TimeDistributed
-from allennlp.nn import util, InitializerApplicator, RegularizerApplicator
-from allennlp_models.coref.metrics.conll_coref_scores import ConllCorefScores
-from allennlp_models.coref.metrics.mention_recall import MentionRecall
+from radgraph.allennlp.data import Vocabulary
+from radgraph.allennlp.models.model import Model
+from radgraph.allennlp.modules.token_embedders import Embedding
+from radgraph.allennlp.modules import FeedForward
+from radgraph.allennlp.modules import TimeDistributed
+from radgraph.allennlp.nn import util, InitializerApplicator, RegularizerApplicator
+from radgraph.allennlp_models.coref.metrics.conll_coref_scores import ConllCorefScores
+from radgraph.allennlp_models.coref.metrics.mention_recall import MentionRecall
 
-from dygie.models import shared
-from dygie.models.entity_beam_pruner import Pruner
+from radgraph.dygie.models import shared
+from radgraph.dygie.models.entity_beam_pruner import Pruner
 
 logger = logging.getLogger(__name__)  # pylint: disable=invalid-name
 
